@@ -14,7 +14,7 @@
 class TestGmlFileFormat : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void parseTest();
     void serializeTest();
 };
